<?php

class core_tiposervicio {
    public $id;
    public $nomtiposervicio;    
}

class core_desconsol_medida {
	public $id;
    public $medida;
}

class core_personal_empresa {
	public $id;
    public $nombreempleado;
	public $credencial;
}

class core_contenedor_danos {
	public $id;
	public $nomdano;
}

class core_materiales_servicio {
	public $id;
	public $idempresa;
	public $nombrematerial;
	public $unidad;
	public $costo;
}

class core_eventos_servicio_timer {
	public $idserevento;
	public $idservicio;
	public $idempresa;
	public $idevento;
	public $nomtipoevento;
	public $fechahora;
	public $notas;
}

class core_servicio_x_estado{
	public $idservicio;
	public $idempresa;
	public $codigotrazabilidad;
	public $importador;
	public $idcliente;
	public $nomcliente;
	public $idclipersonal;
	public $idtipocarga;
	public $nomtipocarga;
	public $imo;
	public $descimo;
	public $iddimcon;
	public $nomdimension;
	public $contenedor;
	public $sellooriginal;
	public $sellonuevo;
	public $cantidad;
	public $peso;
	public $idtiposervicio;
	public $nomtiposervicio;
	public $iddesmed;
	public $nomdesmedida;
	public $notascantidad;
	public $utilizacanino;
	public $usacanino;
	public $notascarga;
	public $revisionnointrusiva;
	public $usarevintrusiva;
	public $muestreomercancia;
	public $usamuestreo;
	public $observacionesmuestreo;
	public $clientefacturar;
	public $montomaterial;
	public $montototal;
	public $fechacaptura;
	public $idusuario;
	public $idestado;
	public $descestado;
}
